#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uglymemo
version:              0.1.0.1
visibility:           public
id:                   uglymemo-0.1.0.1-9CTAG7WaUP4YIMm3gIN93
key:                  uglymemo-0.1.0.1-9CTAG7WaUP4YIMm3gIN93
license:              LicenseRef-PublicDomain
maintainer:           lennart@augustsson.net
author:               Lennart Augustsson
synopsis:             A simple (but internally ugly) memoization function.
description:
    A simple (but internally ugly) memoization function.

    * New in 0.1.0.1: Make it exception safe.

category:             Data
abi:                  0cc2611b8606243fb00a8c9f7aef4bca
exposed:              True
exposed-modules:      Data.MemoUgly
import-dirs:          /usr/lib/ghc-9.6.6/site-local/uglymemo-0.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/uglymemo-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/uglymemo-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uglymemo
hs-libraries:         HSuglymemo-0.1.0.1-9CTAG7WaUP4YIMm3gIN93
depends:              base-4.18.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-uglymemo/html/uglymemo.haddock
haddock-html:         /usr/share/doc/haskell-uglymemo/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

